@@ -6,20 +6,23 @@
  *
  */
 
-#ifndef AKONADI_SEARCH_PIM_CONTACTQUERY_H
-#define AKONADI_SEARCH_PIM_CONTACTQUERY_H
+#pragma once
 
 #include "query.h"
 #include "search_pim_export.h"
 
 #include <QString>
 
+#include <memory>
+
 namespace Akonadi
 {
 namespace Search
 {
 namespace PIM
 {
+class ContactQueryPrivate;
+
 /**
  * Query for a list of contacts matching a criteria
  */
@@ -35,22 +38,23 @@ public:
     void matchUID(const QString &uid);
     void match(const QString &str);
 
-    enum MatchCriteria { ExactMatch, StartsWithMatch };
+    enum MatchCriteria {
+        ExactMatch,
+        StartsWithMatch,
+    };
 
     void setMatchCriteria(MatchCriteria m);
-    MatchCriteria matchCriteria() const;
+    Q_REQUIRED_RESULT MatchCriteria matchCriteria() const;
 
     ResultIterator exec() override;
 
-    int limit() const;
+    Q_REQUIRED_RESULT int limit() const;
     void setLimit(int limit);
 
 private:
-    class Private;
-    Private *const d;
+    std::unique_ptr<ContactQueryPrivate> const d;
 };
 }
 }
 }
 
-#endif // AKONADI_SEARCH_PIM_CONTACTQUERY_H
